@@ -314,6 +314,9 @@ def create_isolinux_image_for_uefi(output_file, deploy_iso, kernel, ramdisk,
 
 def qemu_img_info(path):
     """Return an object containing the parsed output from qemu-img info."""
+    # NOTE(jlvillal): This function has been moved to ironic-lib. And is
+    # planned to be deleted here. If need to modify this function, please also
+    # do the same modification in ironic-lib
     if not os.path.exists(path):
         return imageutils.QemuImgInfo()
 
@@ -324,6 +327,9 @@ def qemu_img_info(path):
 
 def convert_image(source, dest, out_format, run_as_root=False):
     """Convert image to other format."""
+    # NOTE(jlvillal): This function has been moved to ironic-lib. And is
+    # planned to be deleted here. If need to modify this function, please also
+    # do the same modification in ironic-lib
     cmd = ('qemu-img', 'convert', '-O', out_format, source, dest)
     utils.execute(*cmd, run_as_root=run_as_root)
 
@@ -384,10 +390,14 @@ def image_to_raw(image_href, path, path_tmp):
             os.rename(path_tmp, path)
 
 
-def download_size(context, image_href, image_service=None):
-    if not image_service:
+def image_show(context, image_href, image_service=None):
+    if image_service is None:
         image_service = service.get_image_service(image_href, context=context)
-    return image_service.show(image_href)['size']
+    return image_service.show(image_href)
+
+
+def download_size(context, image_href, image_service=None):
+    return image_show(context, image_href, image_service)['size']
 
 
 def converted_size(path):
