@@ -279,10 +279,10 @@ class NeutronDHCPApi(base.BaseDHCP):
                 failures.append(port.uuid)
 
         if failures:
-            LOG.warn(_LW("Some errors were encountered on node %(node)s"
-                         " while retrieving IP address on the following"
-                         " ports: %(ports)s."),
-                     {'node': task.node.uuid, 'ports': failures})
+            LOG.warning(_LW("Some errors were encountered on node %(node)s"
+                            " while retrieving IP address on the following"
+                            " ports: %(ports)s."),
+                        {'node': task.node.uuid, 'ports': failures})
 
         return ip_addresses
 
@@ -320,7 +320,7 @@ class NeutronDHCPApi(base.BaseDHCP):
             if not port.get('port') or not port['port'].get('id'):
                 self._rollback_cleaning_ports(task)
                 msg = (_('Failed to create cleaning ports for node '
-                         '%(node)s') % task.node.uuid)
+                         '%(node)s') % {'node': task.node.uuid})
                 LOG.error(msg)
                 raise exception.NodeCleaningFailure(msg)
             # Match return value of get_node_vif_ids()
