@@ -28,6 +28,7 @@ models.
 """
 
 import abc
+import time
 
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -39,6 +40,7 @@ from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common.i18n import _LW
 from ironic.common import states
+from ironic.common import utils
 from ironic.conductor import task_manager
 from ironic.drivers import base
 
@@ -55,7 +57,14 @@ else:
 opts = [
     cfg.IntOpt('power_timeout',
                default=10,
-               help=_('Seconds to wait for power action to be completed'))
+               help=_('Seconds to wait for power action to be completed')),
+    # NOTE(yuriyz): some of SNMP-enabled hardware have own options for pause
+    # between off and on. This option guarantees minimal value.
+    cfg.IntOpt('reboot_delay',
+               default=0,
+               min=0,
+               help=_('Time (in seconds) to sleep between when rebooting '
+                      '(powering off and on again)'))
 ]
 
 LOG = logging.getLogger(__name__)
@@ -76,13 +85,13 @@ REQUIRED_PROPERTIES = {
 }
 OPTIONAL_PROPERTIES = {
     'snmp_version':
-        _("SNMP protocol version: %(v1)s, %(v2c)s, %(v3)s  "
+        _("SNMP protocol version: %(v1)s, %(v2c)s or %(v3)s  "
           "(optional, default %(v1)s)")
         % {"v1": SNMP_V1, "v2c": SNMP_V2C, "v3": SNMP_V3},
     'snmp_port':
         _("SNMP port, default %(port)d") % {"port": SNMP_PORT},
     'snmp_community':
-        _("SNMP community.  Required for versions %(v1)s, %(v2c)s")
+        _("SNMP community.  Required for versions %(v1)s and %(v2c)s")
         % {"v1": SNMP_V1, "v2c": SNMP_V2C},
     'snmp_security':
         _("SNMP security name.  Required for version %(v3)s")
@@ -310,6 +319,7 @@ class SNMPDriverBase(object):
         power_result = self.power_off()
         if power_result != states.POWER_OFF:
             return states.ERROR
+        time.sleep(CONF.snmp.reboot_delay)
         power_result = self.power_on()
         if power_result != states.POWER_ON:
             return states.ERROR
@@ -594,11 +604,8 @@ def _parse_driver_info(node):
 
     # In absence of a configured UDP port, default to the standard port
     port_str = info.get('snmp_port', SNMP_PORT)
-    try:
-        snmp_info['port'] = int(port_str)
-    except ValueError:
-        raise exception.InvalidParameterValue(_(
-            "SNMPPowerDriver: SNMP UDP port must be numeric: %s") % port_str)
+    snmp_info['port'] = utils.validate_network_port(port_str, 'snmp_port')
+
     if snmp_info['port'] < 1 or snmp_info['port'] > 65535:
         raise exception.InvalidParameterValue(_(
             "SNMPPowerDriver: SNMP UDP port out of range: %d")
