@@ -22,16 +22,19 @@ from oslo_utils import importutils
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.drivers import base
+from ironic.drivers.modules import agent
 from ironic.drivers.modules.amt import management as amt_management
 from ironic.drivers.modules.amt import power as amt_power
 from ironic.drivers.modules.amt import vendor as amt_vendor
 from ironic.drivers.modules.cimc import management as cimc_mgmt
 from ironic.drivers.modules.cimc import power as cimc_power
 from ironic.drivers.modules import iboot
+from ironic.drivers.modules.ilo import console as ilo_console
 from ironic.drivers.modules.ilo import deploy as ilo_deploy
 from ironic.drivers.modules.ilo import inspect as ilo_inspect
 from ironic.drivers.modules.ilo import management as ilo_management
 from ironic.drivers.modules.ilo import power as ilo_power
+from ironic.drivers.modules.ilo import vendor as ilo_vendor
 from ironic.drivers.modules import inspector
 from ironic.drivers.modules import ipminative
 from ironic.drivers.modules import ipmitool
@@ -80,6 +83,7 @@ class PXEAndIPMIToolDriver(base.BaseDriver):
         self.vendor = utils.MixinVendorInterface(
             self.mapping,
             driver_passthru_mapping=self.driver_passthru_mapping)
+        self.raid = agent.AgentRAID()
 
 
 class PXEAndSSHDriver(base.BaseDriver):
@@ -102,6 +106,7 @@ class PXEAndSSHDriver(base.BaseDriver):
         self.vendor = iscsi_deploy.VendorPassthru()
         self.inspect = inspector.Inspector.create_if_enabled(
             'PXEAndSSHDriver')
+        self.raid = agent.AgentRAID()
 
 
 class PXEAndIPMINativeDriver(base.BaseDriver):
@@ -138,6 +143,7 @@ class PXEAndIPMINativeDriver(base.BaseDriver):
                                                  self.driver_passthru_mapping)
         self.inspect = inspector.Inspector.create_if_enabled(
             'PXEAndIPMINativeDriver')
+        self.raid = agent.AgentRAID()
 
 
 class PXEAndSeaMicroDriver(base.BaseDriver):
@@ -206,10 +212,11 @@ class PXEAndIloDriver(base.BaseDriver):
         self.power = ilo_power.IloPower()
         self.boot = pxe.PXEBoot()
         self.deploy = ilo_deploy.IloPXEDeploy()
-        self.vendor = ilo_deploy.IloPXEVendorPassthru()
-        self.console = ilo_deploy.IloConsoleInterface()
+        self.vendor = ilo_vendor.VendorPassthru()
+        self.console = ilo_console.IloConsoleInterface()
         self.management = ilo_management.IloManagement()
         self.inspect = ilo_inspect.IloInspect()
+        self.raid = agent.AgentRAID()
 
 
 class PXEAndSNMPDriver(base.BaseDriver):
@@ -280,6 +287,7 @@ class PXEAndVirtualBoxDriver(base.BaseDriver):
         self.deploy = iscsi_deploy.ISCSIDeploy()
         self.management = virtualbox.VirtualBoxManagement()
         self.vendor = iscsi_deploy.VendorPassthru()
+        self.raid = agent.AgentRAID()
 
 
 class PXEAndAMTDriver(base.BaseDriver):
